@@ -8,7 +8,7 @@ from django.db import models, IntegrityError, transaction
 from django.utils import timezone
 from django.utils.translation import ugettext_lazy as _
 
-from enumfields import NumEnumField
+from enumfields import IntegerEnumField
 
 from chamber.exceptions import PersistenceException
 from chamber.models import SmartModel, SmartQuerySet, SmartManager
@@ -155,6 +155,9 @@ class AuthorizationToken(SmartModel):
         verbose_name = _('authorization token')
         verbose_name_plural = _('authorization tokens')
 
+    class SmartMeta:
+        is_cleaned_pre_save = False
+
     @property
     def active_takeover(self):
         return self.user_takeovers.filter(is_active=True).last()
@@ -427,7 +430,7 @@ class AuthorizationRequest(SmartModel):
         null=True,
         blank=True
     )
-    result = NumEnumField(
+    result = IntegerEnumField(
         verbose_name=_('result'),
         enum=AuthorizationRequestResult,
         null=True,
